@@ -1,6 +1,6 @@
 import os
 import numpy as np
-from pluggy import HookimplMarker
+from napari_plugin_engine import napari_hook_implementation
 from .xml_to_svg import xml_to_svg
 from .layer_to_xml import (
     image_to_xml,
@@ -11,11 +11,10 @@ from .layer_to_xml import (
 
 
 labels_to_xml = image_to_xml
-napari_hook_implementation = HookimplMarker('napari')
 supported_layers = ['image', 'points', 'labels', 'shapes', 'vectors']
 
 
-@napari_hook_implementation
+@napari_hook_implementation(trylast=True)
 def napari_get_writer(path, layer_types):
     """Write layer data to an svg.
 
@@ -88,9 +87,12 @@ def writer(path, layer_data):
         if full_extrema is None:
             full_extrema = extrema
         else:
+            # get the extreema of all elements.
+            # elements with nan extreema (i.e., empty) will not be considered for min/max.
+            # see https://github.com/napari/napari-svg/pull/12
             full_extrema = np.array([
-                                np.min([full_extrema[0], extrema[0]], axis=0),
-                                np.max([full_extrema[1], extrema[1]], axis=0),
+                                np.nanmin([full_extrema[0], extrema[0]], axis=0),
+                                np.nanmax([full_extrema[1], extrema[1]], axis=0),
                             ])
 
     # Generate svg string
@@ -103,20 +105,20 @@ def writer(path, layer_data):
     return path
 
 
-@napari_hook_implementation
+@napari_hook_implementation(trylast=True)
 def napari_write_image(path, data, meta):
     """Write image data to an svg.
 
-    Only two dimensional image data is supported (including rgb, and pyramid).
-    For pyramid data the lowest resolution is used.
+    Only two dimensional image data is supported (including rgb, and multiscale).
+    For multiscale data the lowest resolution is used.
 
     Parameters
     ----------
     path : str
         Path to file, directory, or resource (like a URL).
     data : array or list of array
-        Image data. Only two dimensional data (including rgb, and pyramid)
-        is supported. For pyramid data the lowest resolution is used.
+        Image data. Only two dimensional data (including rgb, and multiscale)
+        is supported. For multiscale data the lowest resolution is used.
     meta : dict
         Image metadata.
 
@@ -147,20 +149,20 @@ def napari_write_image(path, data, meta):
 
 
 
-@napari_hook_implementation
+@napari_hook_implementation(trylast=True)
 def napari_write_labels(path, data, meta):
     """Write labels data to an svg.
 
-    Only two dimensional labels data is supported (including pyramid).
-    For pyramid data the lowest resolution is used.
+    Only two dimensional labels data is supported (including multiscale).
+    For multiscale data the lowest resolution is used.
 
     Parameters
     ----------
     path : str
         Path to file, directory, or resource (like a URL).
     data : array or list of array
-        Labels data. Only two dimensional data (including pyramid) is supported.
-        For pyramid data the lowest resolution is used.
+        Labels data. Only two dimensional data (including multiscale) is supported.
+        For multiscale data the lowest resolution is used.
     meta : dict
         Labels metadata.
 
